/*
 * (c) 2006-2017 Thomas Maier-Komor
 * LICENSE: GPLv2, see file COPYING for details
 */

#ifndef SUPPORT_H
#define SUPPORT_H

#include <assert.h>
#include <fcntl.h>
#include <string.h>
#include <sys/time.h>


void *Malloc(size_t s);
int read_to_0(void);
int read_to_nl(void);
int resolve_symlink(char *cmd);
char *complete_exe(char *exe);
const char *timestr(long long usec, char *ustr);
char *concatstr(const char *s0, const char *s1);
char *makestr(const char *f, ...);

#ifdef __sun
#define gettime() (gethrtime()/1000)
#else
static inline unsigned long long gettime(void)
{
	struct timeval now;
	
	(void) gettimeofday(&now,0);
	return now.tv_sec * 1000000 + now.tv_usec;
}
#endif


static inline void close_onexec(int f)
{
	if (f != -1) {
		int err = fcntl(f,F_SETFD,FD_CLOEXEC);
		assert(err != -1);
	}
}


static inline char *Strdup(const char *s)
{
	assert(s != 0);
	size_t n = strlen(s) + 1;
	return memcpy(Malloc(n),s,n);
}


static inline char *Strdupn(const char *s, size_t n)
{
	assert(s != 0);
	return memcpy(Malloc(n),s,n);
}


static inline const char *timevstr(struct timeval t, char *ustr)
{
	long long dt = t.tv_sec * 1000000 + t.tv_usec;
	return timestr(dt,ustr);
}



#endif
